@@ -11,35 +11,35 @@
 #' @example examples/get_fun.R
 
 get_fun <- function(fn, default = identity) {
-  fn_input <- rlang::as_label(rlang::enexpr(fn))
+  if (try_true(is.function(fn))) {return(fn)}
+  if (try_true(is.null(fn)))     {return(get_fun(default))}
 
-  if (fn_input == "default") {
-    fn_input <- deparse(substitute(default, env = sys.frame(-1)))
-  } else if (fn_input == "n_fn") {
-    fn_input <- deparse(substitute(n_fn,    env = sys.frame(-1)))
-  }
-
-  env <- rlang::current_env()
-
-  if (try_true(is.null(fn))) {return(get_fun(default))}
+  env <- parent.frame()
 
   if (try_true(is.character(fn))) {
     fn_input <- fn
 
-    if (grepl("::", fn)) {
-      package  <- gsub("::.*$", "", fn)
-      fn       <- gsub("^.*::", "", fn)
+    if (grepl("::", fn_input)) {
+      fn       <- gsub("^.*::", "", fn_input)
+      package  <- gsub("::.*$", "", fn_input)
       env      <- getNamespace(package)
     }
+  } else {
+    fn_input <- deparse(substitute(fn))
+    fn       <- fn_input
+  }
+
+  if (fn_input == "default") {
+    fn       <- deparse(substitute(default, env = env))
+    fn_input <- fn
+  } else if (fn_input == "n_fn") {
+    fn       <- deparse(substitute(n_fn, env = env))
+    fn_input <- fn
   }
 
   tryCatch(
-    suppressWarnings(rlang::as_function(fn, env = env)),
-    error = function(e) {
-      rlang::abort(
-        paste0("Could not find the function `", fn_input, "`")
-      )
-    }
+    suppressWarnings(get(fn, envir = env, mode = "function")),
+    error = function(e) {error("Could not find the function ", code(fn_input))}
   )
 }
 
